<?php
/**
 * Pocket Project
 * 
 * @copyright 2006 Power-Station co., Ltd, ALL Rights Reserved,
 */

/**
 *  指定トラックバック情報の取得
 *
 *  @access public
 *  @param  integer $trackback_id       トラックバックID
 */
function db_get_trackback4delete($trackback_id)
{
    $sql = 'SELECT trackback_id, post_id, title, url, excerpt, blog_name, ip, r_datetime' .
            ' FROM pb_trackbacks' .
            ' WHERE trackback_id = ?';
    $params = array(
        intval($trackback_id)
    );
    return pocket_db_getRow($sql, $params);
}

/**
 *  指定記事のトラックバック情報の取得
 *
 *  @access public
 *  @param  integer $post_id            記事ID
 */
function db_get_trackbacks4post_comment($post_id)
{
    $sql = 'SELECT trackback_id, post_id, title, url, excerpt, blog_name, ip, r_datetime' .
            ' FROM pb_trackbacks' .
            ' WHERE post_id = ?' .
            ' AND is_approved = ?' .
            ' ORDER BY r_datetime DESC';
    $params = array(
        intval($post_id),
        intval(true)
    );
    return pocket_db_getAll($sql, $params);
}

/**
 *  最新のトラックバック一覧情報の取得
 *
 *  @access public
 *  @param  integer $page               ページ番号
 *  @param  integer $page_size          ページサイズ
 */
function db_get_trackbacks4latest_trackback_list($page = 1, $page_size = 5)
{
    $sql = 'SELECT tb.trackback_id, tb.post_id, tb.title, tb.excerpt, tb.blog_name, tb.r_datetime' .
            ' FROM pb_trackbacks AS tb' .
            ' LEFT JOIN pb_posts AS p' .
                ' ON tb.post_id = p.post_id' .
            ' WHERE p.is_open = ?' .
            ' AND tb.is_approved = ?' .
            ' ORDER BY tb.r_datetime DESC';
    $params = array(
        intval(true),
        intval(true)
    );
    return pocket_db_getAllPage($sql, $page, $page_size, $params);
}

/**
 *  最新のトラックバック一覧情報（RSS用）の取得
 *
 *  @access public
 *  @param  integer $page_size          ページサイズ
 */
function db_get_trackbacks4latest_trackback_rss($page_size = 5)
{
    $sql = 'SELECT tb.trackback_id, tb.post_id, tb.title, tb.excerpt AS description, tb.r_datetime' .
            ' FROM pb_trackbacks AS tb' .
            ' LEFT JOIN pb_posts AS p' .
                ' ON tb.post_id = p.post_id' .
            ' WHERE p.is_open = ?' .
            ' AND tb.is_approved = ?' .
            ' ORDER BY tb.r_datetime DESC';
    $params = array(
        intval(true),
        intval(true)
    );
    return pocket_db_getAllPage($sql, 1, $page_size, $params);
}

/**
 *  未承認のトラックバック情報の取得
 *
 *  @access public
 *  @param  integer $page               ページ番号
 *  @param  integer $page_size          ページサイズ
 */
function db_get_trackbacks4unapproved($page = 1, $page_size = 5)
{
    $sql = 'SELECT e.post_id, e.category_id, ca.category_name, e.subject,' .
            ' tb.trackback_id, tb.title, tb.url, tb.excerpt, tb.blog_name, tb.r_datetime' .
            ' FROM pb_posts AS e' .
            ' LEFT JOIN pb_trackbacks AS tb' .
                ' ON e.post_id = tb.post_id' .
            ' LEFT JOIN pb_categories AS ca' .
                ' ON e.category_id = ca.category_id' .
            ' WHERE tb.is_approved = ?' .
            ' ORDER BY tb.r_datetime DESC';
    $params = array(
        intval(false)
    );
    return pocket_db_getAllPage($sql, $page, $page_size, $params);
}

/**
 *  未承認のトラックバック件数の取得
 *
 *  @access public
 */
function db_get_trackbacks_count4unapproved()
{
    $sql = 'SELECT count(trackback_id)' .
            ' FROM pb_trackbacks' .
            ' WHERE is_approved = ?';
    $params = array(
        intval(false)
    );
    return pocket_db_getOne($sql, $params);
}

/**
 *  トラックバック情報の登録
 *
 *  @access public
 *  @param  integer $post_id            記事ID
 *  @param  integer $is_approved        承認フラグ
 *  @param  string  $title              タイトル
 *  @param  string  $url                URL
 *  @param  string  $excerpt            概要
 *  @param  string  $blog_name          ブログ名称
 *  @param  string  $ip                 IPアドレス
 */
function db_insert_trackback($post_id, $is_approved, $title, $url, $excerpt, $blog_name, $ip)
{
    $data = array(
        'post_id' => $post_id,
        'is_approved' => intval($is_approved),
        'title' => $title,
        'url' => $url,
        'excerpt' => $excerpt,
        'blog_name' => $blog_name,
        'ip' => $ip,
        'r_datetime' => pocket_db_getNow()
    );
    return pocket_db_insert('pb_trackbacks', $data, 'pb_trackbacks_trackback_id_seq');
}

/**
 *  トラックバック情報の承認
 *
 *  @access public
 *  @param  integer $trackback_id       トラックバックID
 */
function db_update_trackback4approve($trackback_id)
{
    $data = array(
        'is_approved' => intval(true)
    );
    $where = array(
        'trackback_id' => intval($trackback_id)
    );
    return pocket_db_update('pb_trackbacks', $data, $where);
}

/**
 *  トラックバック情報の削除（ID用）
 *
 *  @access public
 *  @param  integer $trackback_id       トラックバックID
 */
function db_delete_trackback4id($trackback_id)
{
    return pocket_db_delete('pb_trackbacks', 'trackback_id', intval($trackback_id));
}

/**
 *  トラックバック情報の削除（URL用）
 *
 *  @access public
 *  @param  string  $url                URL
 */
function db_delete_trackback4url($url)
{
    return pocket_db_delete('pb_trackbacks', 'url', $url);
}

?>
